# Prof.Li's Python Education Tools
## 道法自然
## **pip install -U python-education-tools**
**sample code as follows:**
`````import numpy as np
import pet.that
`````

![hah](https://upload.wikimedia.org/wikipedia/commons/thumb/e/eb/Taijitu_06075171.jpg/440px-Taijitu_06075171.jpg)